From: agk@sourceware.org <agk@sourceware.org>
To: lvm-devel@redhat.com
Subject: LVM2 ./WHATS_NEW lib/locking/locking.c
Date: 8 May 2008 18:35:59 -0000 [thread overview]
Message-ID: <20080508183559.4540.qmail@sourceware.org> (raw)
CVSROOT: /cvs/lvm2
Module name: LVM2
Changes by: agk at sourceware.org 2008-05-08 18:35:58
Modified files:
. : WHATS_NEW
lib/locking : locking.c
Log message:
Avoid unnecessary unlock attempts with LCK_CACHE pseudo-locks.
Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/WHATS_NEW.diff?cvsroot=lvm2&r1=1.869&r2=1.870
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/lib/locking/locking.c.diff?cvsroot=lvm2&r1=1.47&r2=1.48
--- LVM2/WHATS_NEW 2008/05/08 18:28:27 1.869
+++ LVM2/WHATS_NEW 2008/05/08 18:35:58 1.870
@@ -5,6 +5,7 @@
Version 2.02.37 -
=================================
+ Avoid unnecessary unlock attempts with LCK_CACHE pseudo-locks.
When asked to drop cached committed VG metadata, invalidate cached PV labels.
Drop metadata cache before writing precommitted metadata instead of after.
Don't touch /dev in vgrename if activation is disabled.
--- LVM2/lib/locking/locking.c 2008/04/15 14:46:19 1.47
+++ LVM2/lib/locking/locking.c 2008/05/08 18:35:58 1.48
@@ -370,8 +370,12 @@
if (!_lock_vol(cmd, resource, flags))
return 0;
- /* Perform immediate unlock unless LCK_HOLD set */
- if (!(flags & LCK_HOLD) && ((flags & LCK_TYPE_MASK) != LCK_UNLOCK)) {
+ /*
+ * If a real lock was acquired (i.e. not LCK_CACHE),
+ * perform an immediate unlock unless LCK_HOLD was requested.
+ */
+ if (!(flags & LCK_CACHE) && !(flags & LCK_HOLD) &&
+ ((flags & LCK_TYPE_MASK) != LCK_UNLOCK)) {
if (!_lock_vol(cmd, resource,
(flags & ~LCK_TYPE_MASK) | LCK_UNLOCK))
return 0;
next reply other threads:[~2008-05-08 18:35 UTC|newest]
Thread overview: 10+ messages / expand[flat|nested] mbox.gz Atom feed top
2008-05-08 18:35 agk [this message]
-- strict thread matches above, loose matches on Subject: below --
2012-03-27 15:53 LVM2 ./WHATS_NEW lib/locking/locking.c mbroz
2011-08-10 16:07 mbroz
2011-01-13 14:56 zkabelac
2010-03-31 17:23 mbroz
2010-01-13 17:40 mbroz
2009-11-23 10:55 mbroz
2009-07-14 11:01 agk
2009-02-22 16:13 agk
2006-10-14 16:37 agk
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20080508183559.4540.qmail@sourceware.org \
--to=agk@sourceware.org \
--cc=lvm-devel@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.